/**
 * Copyright (C) 2016-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtabs.demo.tabs;

import java.util.LinkedHashMap;
import java.util.Map;

import org.dussan.vaadin.dtabs.demo.tabs.summary.TabsSummary;
import org.dussan.vaadin.dtabs.demo.tabs.top.BasicTabs;
import org.dussan.vaadin.dtabs.demo.tabs.top.CenteredTabs;
import org.dussan.vaadin.dtabs.demo.tabs.top.CompactedTabbar;
import org.dussan.vaadin.dtabs.demo.tabs.top.EqualWidthTabs;
import org.dussan.vaadin.dtabs.demo.tabs.top.UnframedTabs;
import org.dussan.vaadin.dtabs.demo.tabs.top.IconsOnTop;
import org.dussan.vaadin.dtabs.demo.tabs.top.OnlySelectedTabIsCloseable;
import org.dussan.vaadin.dtabs.demo.tabs.top.PaddedTabbar;
import org.dussan.vaadin.dtabs.demo.tabs.top.RightAlignedTabs;
import org.dussan.vaadin.dtabs.demo.tabs.top.TabsWithProperties;
import org.dussan.vaadin.dtabs.demo.tabs.types.TopTabTypes;
import org.dussan.vaadin.dtabs.demo.ui.tree.TabTypes;
import org.dussan.vaadin.dtabs.demo.ui.tree.TabsTree;

import com.vaadin.ui.Component;
import com.vaadin.ui.Tree;

public class TopTabs
{

    private TopTabs()
    {
    }

    public static void addTabs( final Tree tree )
    {
        String parent = TopTabTypes.values()[0].getPath();
        tree.addItem( parent );
        tree.setItemCaption( parent, TopTabTypes.values()[0].getDescription() );
        for ( int tab = 1; tab < TopTabTypes.values().length; tab++ )
        {
            String item = parent + TabsTree.PATH_DELIMITER + TopTabTypes.values()[tab].getPath();
            String itemValue = TopTabTypes.values()[tab].getDescription();
            tree.addItem( item );
            tree.setItemCaption( item, itemValue );
            tree.setParent( item, parent );
            tree.setChildrenAllowed( item, false );
        }
        tree.expandItemsRecursively( parent );
    }

    public static Component processTab( String tab )
    {
        Component component = null;
        switch ( TopTabTypes.fromString( tab ) )
        {
            case BASIC:
                component = new BasicTabs();
                break;
            case CENTERED_TABS:
                component = new CenteredTabs();
                break;
            case COMPACTED_TABBAR:
                component = new CompactedTabbar();
                break;
            case EQUAL_WIDTH_TABS:
                component = new EqualWidthTabs();
                break;
            case ICONS_ON_TOP:
                component = new IconsOnTop();
                break;
            case ONLY_SELECTED_TAB_IS_CLOSABLE:
                component = new OnlySelectedTabIsCloseable();
                break;
            case PADDED_TABBAR:
                component = new PaddedTabbar();
                break;
            case RIGHT_ALIGNED_TABS:
                component = new RightAlignedTabs();
                break;
            case TABS_WITH_PROPERTIES:
                component = new TabsWithProperties();
                break;
            case UNFRAMED_TABS:
                component = new UnframedTabs();
                break;
            case DEFAULT:
            default:
                Map<String, Map<String, String[]>> tabs = new LinkedHashMap<String, Map<String, String[]>>();
                tabs.put( TabTypes.TOP.getPath(), getTabs() );
                component = new TabsSummary( tabs );
                break;
        }
        return component;
    }

    public static Map<String, String[]> getTabs()
    {
        Map<String, String[]> tabs = new LinkedHashMap<String, String[]>();
        for ( TopTabTypes tab : TopTabTypes.values() )
        {
            tabs.put( tab.getPath(), new String[] { tab.getDescription(), tab.getLongDescription() } );
        }
        return tabs;
    }

}
